@@ -5,21 +5,13 @@
 
 requestLongerTimeout(4);
 
-ChromeUtils.defineModuleGetter(
-  this,
-  "ExtensionSettingsStore",
-  "resource://gre/modules/ExtensionSettingsStore.jsm"
-);
-ChromeUtils.defineModuleGetter(
-  this,
-  "AboutNewTab",
-  "resource:///modules/AboutNewTab.jsm"
-);
-ChromeUtils.defineModuleGetter(
-  this,
-  "ExtensionControlledPopup",
-  "resource:///modules/ExtensionControlledPopup.jsm"
-);
+ChromeUtils.defineESModuleGetters(this, {
+  AboutNewTab: "resource:///modules/AboutNewTab.sys.mjs",
+  ExtensionControlledPopup:
+    "resource:///modules/ExtensionControlledPopup.sys.mjs",
+  ExtensionSettingsStore:
+    "resource://gre/modules/ExtensionSettingsStore.sys.mjs",
+});
 
 function getNotificationSetting(extensionId) {
   return ExtensionSettingsStore.getSetting("newTabNotification", extensionId);
@@ -53,7 +45,7 @@ async function promiseNewTab(expectUrl = AboutNewTab.newTabURL, win = window) {
     `Should open correct new tab url ${expectUrl}.`
   );
 
-  win.BrowserOpenTab();
+  win.BrowserCommands.openTab();
   const newTabCreatedPromise = newTabStartPromise;
   const browser = await newTabCreatedPromise;
   await newtabShown;
@@ -152,8 +144,9 @@ add_task(async function test_new_tab_ignore_settings() {
     useAddonManager: "temporary",
   });
 
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is initially closed"
   );
 
@@ -188,8 +181,9 @@ add_task(async function test_new_tab_ignore_settings() {
   await popupHidden;
 
   // Ensure panel is closed and the setting still isn't set.
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is closed"
   );
   is(
@@ -203,8 +197,9 @@ add_task(async function test_new_tab_ignore_settings() {
   tab = await promiseNewTab();
 
   // Verify the doorhanger is not shown a second time.
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel doesn't open after ignoring the doorhanger"
   );
   is(gURLBar.focused, true, "The URL bar is focused with no doorhanger");
@@ -230,8 +225,9 @@ add_task(async function test_new_tab_keep_settings() {
     useAddonManager: "permanent",
   });
 
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is initially closed"
   );
 
@@ -278,8 +274,9 @@ add_task(async function test_new_tab_keep_settings() {
   await confirmationSaved;
 
   // Ensure panel is closed and setting is updated.
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is closed after click"
   );
   is(
@@ -293,8 +290,9 @@ add_task(async function test_new_tab_keep_settings() {
   tab = await promiseNewTab(extensionNewTabUrl);
 
   // Verify the doorhanger is not shown a second time.
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is not opened after keeping the changes"
   );
 
@@ -312,8 +310,9 @@ add_task(async function test_new_tab_keep_settings() {
   tab = await promiseNewTab(extensionNewTabUrl);
 
   // Ensure panel is closed and setting is still set.
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is closed after click"
   );
   is(
@@ -348,8 +347,9 @@ add_task(async function test_new_tab_restore_settings() {
     useAddonManager: "temporary",
   });
 
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is initially closed"
   );
   is(
@@ -391,8 +391,9 @@ add_task(async function test_new_tab_restore_settings() {
   await preferencesShown;
 
   // Ensure panel is closed, settings haven't changed and add-on is disabled.
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is closed after click"
   );
 
@@ -406,8 +407,9 @@ add_task(async function test_new_tab_restore_settings() {
   BrowserTestUtils.removeTab(tab);
   tab = await promiseNewTab();
 
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is not opened after keeping the changes"
   );
 
@@ -442,8 +444,9 @@ add_task(async function test_new_tab_restore_settings_multiple() {
     useAddonManager: "temporary",
   });
 
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is initially closed"
   );
   is(
@@ -547,8 +550,9 @@ add_task(async function test_new_tab_restore_settings_multiple() {
   await addonDisabled;
   tab2 = await promiseNewTab();
 
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is closed after restoring the second time"
   );
   is(
@@ -566,8 +570,9 @@ add_task(async function test_new_tab_restore_settings_multiple() {
   BrowserTestUtils.removeTab(tab2);
   tab2 = await promiseNewTab();
 
-  ok(
-    panel.getAttribute("panelopen") != "true",
+  Assert.notEqual(
+    panel.getAttribute("panelopen"),
+    "true",
     "The notification panel is not opened after keeping the changes"
   );
 
@@ -613,7 +618,7 @@ add_task(async function dontTemporarilyShowAboutExtensionPath() {
 
   gBrowser.removeProgressListener(wpl);
   is(gURLBar.value, "", "URL bar value should be empty.");
-  await SpecialPowers.spawn(tab.linkedBrowser, [], function() {
+  await SpecialPowers.spawn(tab.linkedBrowser, [], function () {
     is(
       content.document.body.textContent,
       "New tab!",
