@@ -155,8 +155,8 @@ async function makeSureProfilerPopupIsEnabled() {
   info("Make sure the profiler popup is enabled.");
 
   info("> Load the profiler menu button.");
-  const { ProfilerMenuButton } = ChromeUtils.import(
-    "resource://devtools/client/performance-new/popup/menu-button.jsm.js"
+  const { ProfilerMenuButton } = ChromeUtils.importESModule(
+    "resource://devtools/client/performance-new/popup/menu-button.sys.mjs"
   );
 
   if (!ProfilerMenuButton.isInNavbar()) {
@@ -499,9 +499,19 @@ async function withDevToolsPanel(url, callback, aWindow = window) {
 
   info("About to remove the about:blank tab");
   await toolbox.destroy();
+
+  // The previous asynchronous functions may resolve within a tick after opening a new tab.
+  // We shouldn't remove the newly opened tab in the same tick.
+  // Wait for the next tick here.
+  await TestUtils.waitForTick();
+
+  // Take care to register the TabClose event before we call removeTab, to avoid
+  // race issues.
+  const waitForClosingPromise = BrowserTestUtils.waitForTabClosing(tab);
   BrowserTestUtils.removeTab(tab);
+  info("Requested closing the about:blank tab, waiting...");
+  await waitForClosingPromise;
   info("The about:blank tab is now removed.");
-  await new Promise(resolve => setTimeout(resolve, 500));
 }
 /* exported withDevToolsPanel */
 
@@ -514,8 +524,8 @@ async function withDevToolsPanel(url, callback, aWindow = window) {
  * @returns {Object}
  */
 function getActiveConfiguration() {
-  const BackgroundJSM = ChromeUtils.import(
-    "resource://devtools/client/performance-new/shared/background.jsm.js"
+  const BackgroundJSM = ChromeUtils.importESModule(
+    "resource://devtools/client/performance-new/shared/background.sys.mjs"
   );
 
   const { startProfiler, stopProfiler } = BackgroundJSM;
@@ -727,8 +737,8 @@ async function makeSureProfilerPopupIsDisabled() {
   info("Make sure the profiler popup is dsiabled.");
 
   info("> Load the profiler menu button module.");
-  const { ProfilerMenuButton } = ChromeUtils.import(
-    "resource://devtools/client/performance-new/popup/menu-button.jsm.js"
+  const { ProfilerMenuButton } = ChromeUtils.importESModule(
+    "resource://devtools/client/performance-new/popup/menu-button.sys.mjs"
   );
 
   const isOriginallyInNavBar = ProfilerMenuButton.isInNavbar();
@@ -758,8 +768,7 @@ function withWebChannelTestDocument(callback) {
   return BrowserTestUtils.withNewTab(
     {
       gBrowser,
-      url:
-        "http://example.com/browser/devtools/client/performance-new/test/browser/webchannel.html",
+      url: "http://example.com/browser/devtools/client/performance-new/test/browser/webchannel.html",
     },
     callback
   );
