@@ -181,8 +181,9 @@ async function testCpu(element, total, slope, assumptions) {
       let computedPercentage = Number.parseFloat(extractedPercentage);
       Assert.ok(
         isCloseEnough(computedPercentage, slope * 100),
-        `The displayed approximation of the slope is reasonable: ${computedPercentage} vs ${slope *
-          100}`
+        `The displayed approximation of the slope is reasonable: ${computedPercentage} vs ${
+          slope * 100
+        }`
       );
       // Also, sanity checks.
       Assert.ok(
@@ -276,12 +277,8 @@ async function testMemory(element, total, delta, assumptions) {
     null,
     `Can we parse ${element.title} with ${MEMORY_TOOLTIP_REGEXP}?`
   );
-  let [
-    ,
-    extractedDeltaSign,
-    extractedDeltaTotal,
-    extractedDeltaUnit,
-  ] = extracted;
+  let [, extractedDeltaSign, extractedDeltaTotal, extractedDeltaUnit] =
+    extracted;
   if (extractedDeltaSign == null) {
     Assert.equal(delta || 0, 0);
     return;
@@ -447,7 +444,7 @@ async function testAboutProcessesWithConfig({ showAllFrames, showThreads }) {
 
   info("Setting up example.com");
   // Another tab that we'll pretend is hung.
-  let promiseTabHung = (async function() {
+  let promiseTabHung = (async function () {
     let tab = BrowserTestUtils.addTab(gBrowser, "http://example.com", {
       skipAnimation: true,
     });
@@ -467,7 +464,7 @@ async function testAboutProcessesWithConfig({ showAllFrames, showThreads }) {
 
   let promiseAudioPlayback = setupAudioTab();
 
-  let promiseUserContextTab = (async function() {
+  let promiseUserContextTab = (async function () {
     let tab = BrowserTestUtils.addTab(gBrowser, "http://example.com", {
       userContextId: 1,
       skipAnimation: true,
@@ -546,7 +543,7 @@ async function testAboutProcessesWithConfig({ showAllFrames, showThreads }) {
 
   // Keep informing about:processes that `tabHung` is hung.
   // Note: this is a background task, do not `await` it.
-  let fakeProcessHangMonitor = async function() {
+  let fakeProcessHangMonitor = async function () {
     for (let i = 0; i < 100; ++i) {
       if (!tabHung.linkedBrowser) {
         // Let's stop spamming as soon as we can.
@@ -655,9 +652,11 @@ async function testAboutProcessesWithConfig({ showAllFrames, showThreads }) {
     } else {
       Assert.ok(threads, "We have a thread summary row");
 
-      let { number, active = 0, list } = doc.l10n.getAttributes(
-        threads.children[0].children[1]
-      ).args;
+      let {
+        number,
+        active = 0,
+        list,
+      } = doc.l10n.getAttributes(threads.children[0].children[1]).args;
 
       info("Sanity checks: number of threads");
       Assert.greaterOrEqual(
@@ -847,9 +846,8 @@ async function testAboutProcessesWithConfig({ showAllFrames, showThreads }) {
   info("Double-clicking on the extensions process");
   let tabPromise = BrowserTestUtils.waitForNewTab(gBrowser, "about:addons");
   await SpecialPowers.spawn(tabAboutProcesses.linkedBrowser, [], async () => {
-    let extensionsRow = content.document.getElementsByClassName(
-      "extensions"
-    )[0];
+    let extensionsRow =
+      content.document.getElementsByClassName("extensions")[0];
     Assert.ok(!!extensionsRow, "We should have found the extensions process");
     let evt = new content.window.MouseEvent("dblclick", {
       bubbles: true,
