@@ -15,7 +15,7 @@ function waitStoragePermission() {
   });
 }
 
-add_setup(async function() {
+add_setup(async function () {
   info("Starting subResources test");
 
   await SpecialPowers.flushPrefEnv();
@@ -93,7 +93,7 @@ async function runTestWindowOpenHeuristic(disableHeuristics) {
       info("Checking if storage access is denied");
       await new content.Promise(resolve => {
         let ifr = content.document.createElement("iframe");
-        ifr.onload = function() {
+        ifr.onload = function () {
           info("Sending code to the 3rd party content");
           ifr.contentWindow.postMessage(msg, "*");
         };
@@ -131,7 +131,7 @@ async function runTestWindowOpenHeuristic(disableHeuristics) {
 
   info("Cleaning up.");
   await new Promise(resolve => {
-    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, value =>
+    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, () =>
       resolve()
     );
   });
@@ -178,7 +178,7 @@ add_task(async function testDoublyNestedWindowOpenHeuristic() {
       info("Checking if storage access is denied");
       await new content.Promise(resolve => {
         let ifr = content.document.createElement("iframe");
-        ifr.onload = function() {
+        ifr.onload = function () {
           info("Sending code to the 3rd party content");
           ifr.contentWindow.postMessage(msg, "*");
         };
@@ -213,10 +213,10 @@ add_task(async function testDoublyNestedWindowOpenHeuristic() {
   BrowserTestUtils.removeTab(tab);
 });
 
-add_task(async function() {
+add_task(async function () {
   info("Cleaning up.");
   await new Promise(resolve => {
-    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, value =>
+    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, () =>
       resolve()
     );
   });
@@ -296,8 +296,7 @@ async function runTestUserInteractionHeuristic(disableHeuristics) {
         let windowClosed = new content.Promise(resolve => {
           Services.ww.registerNotification(function notification(
             aSubject,
-            aTopic,
-            aData
+            aTopic
           ) {
             // We need to check the document URI for Fission. It's because the
             // 'domwindowclosed' would be triggered twice, one for the
@@ -418,8 +417,7 @@ async function runTestUserInteractionHeuristic(disableHeuristics) {
         let windowClosed = new content.Promise(resolve => {
           Services.ww.registerNotification(function notification(
             aSubject,
-            aTopic,
-            aData
+            aTopic
           ) {
             // We need to check the document URI here as well for the same
             // reason above.
@@ -479,7 +477,7 @@ async function runTestUserInteractionHeuristic(disableHeuristics) {
 
   info("Cleaning up.");
   await new Promise(resolve => {
-    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, value =>
+    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, () =>
       resolve()
     );
   });
@@ -564,8 +562,7 @@ add_task(async function testDoublyNestedUserInteractionHeuristic() {
       let windowClosed = new content.Promise(resolve => {
         Services.ww.registerNotification(function notification(
           aSubject,
-          aTopic,
-          aData
+          aTopic
         ) {
           if (aTopic == "domwindowclosed") {
             Services.ww.unregisterNotification(notification);
@@ -674,8 +671,7 @@ add_task(async function testDoublyNestedUserInteractionHeuristic() {
       let windowClosed = new content.Promise(resolve => {
         Services.ww.registerNotification(function notification(
           aSubject,
-          aTopic,
-          aData
+          aTopic
         ) {
           if (aTopic == "domwindowclosed") {
             Services.ww.unregisterNotification(notification);
@@ -726,13 +722,13 @@ add_task(async function testDoublyNestedUserInteractionHeuristic() {
   BrowserTestUtils.removeTab(tab);
 });
 
-add_task(async function() {
+add_task(async function () {
   info("Wait until the storage permission is ready before cleaning up.");
   await waitStoragePermission();
 
   info("Cleaning up.");
   await new Promise(resolve => {
-    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, value =>
+    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, () =>
       resolve()
     );
   });
@@ -776,7 +772,7 @@ async function runTestFirstPartyWindowOpenHeuristic(disableHeuristics) {
 
       await new content.Promise(resolve => {
         let ifr = content.document.createElement("iframe");
-        ifr.onload = function() {
+        ifr.onload = function () {
           info("Sending code to the 3rd party content");
           ifr.contentWindow.postMessage(msg.blockingCallback, "*");
         };
@@ -893,7 +889,7 @@ async function runTestFirstPartyWindowOpenHeuristic(disableHeuristics) {
 
   info("Cleaning up.");
   await new Promise(resolve => {
-    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, value =>
+    Services.clearData.deleteData(Ci.nsIClearDataService.CLEAR_ALL, () =>
       resolve()
     );
   });
@@ -907,6 +903,6 @@ add_task(async function testFirstPartyWindowOpenHeuristicDisabled() {
   await runTestFirstPartyWindowOpenHeuristic(true);
 });
 
-add_task(async function() {
+add_task(async function () {
   UrlClassifierTestUtils.cleanupTestTrackers();
 });
