@@ -3,16 +3,12 @@
 
 "use strict";
 
-const { SiteDataTestUtils } = ChromeUtils.import(
-  "resource://testing-common/SiteDataTestUtils.jsm"
+const { SiteDataTestUtils } = ChromeUtils.importESModule(
+  "resource://testing-common/SiteDataTestUtils.sys.mjs"
 );
 
-const {
-  MODE_DISABLED,
-  MODE_REJECT,
-  MODE_REJECT_OR_ACCEPT,
-  MODE_UNSET,
-} = Ci.nsICookieBannerService;
+const { MODE_DISABLED, MODE_REJECT, MODE_REJECT_OR_ACCEPT, MODE_UNSET } =
+  Ci.nsICookieBannerService;
 
 const TEST_MODES = [
   MODE_DISABLED,
@@ -90,7 +86,7 @@ async function reloadBrowser(browser, url) {
   let reloaded = BrowserTestUtils.browserLoaded(browser, false, url);
 
   // Reload as a user.
-  window.BrowserReload();
+  window.BrowserCommands.reload();
 
   await reloaded;
 }
@@ -106,9 +102,9 @@ async function openLookUpTelemetryTestPage(browser, testInTop, page, domain) {
   let clickFinishPromise = promiseBannerClickingFinish(domain);
 
   if (testInTop) {
-    BrowserTestUtils.loadURIString(browser, page);
+    BrowserTestUtils.startLoadingURIString(browser, page);
   } else {
-    BrowserTestUtils.loadURIString(browser, TEST_ORIGIN_C);
+    BrowserTestUtils.startLoadingURIString(browser, TEST_ORIGIN_C);
     await BrowserTestUtils.browserLoaded(browser);
 
     await SpecialPowers.spawn(browser, [page], async testURL => {
@@ -122,7 +118,7 @@ async function openLookUpTelemetryTestPage(browser, testInTop, page, domain) {
   await clickFinishPromise;
 }
 
-add_setup(async function() {
+add_setup(async function () {
   // Clear telemetry before starting telemetry test.
   Services.fog.testResetFOG();
 
@@ -204,6 +200,9 @@ add_task(async function test_rule_lookup_telemetry_no_rule() {
   for (let context of ["top", "iframe"]) {
     let isTop = context === "top";
 
+    // Clear the executed records before testing.
+    Services.cookieBanners.removeAllExecutedRecords(false);
+
     // Open a test domain. We should record a rule miss because there is no rule
     // right now
     info("Open a test domain.");
@@ -231,6 +230,8 @@ add_task(async function test_rule_lookup_telemetry_no_rule() {
     verifyLookUpTelemetry("ruleLookupByLoad", expectedTelemetryOnce);
     verifyLookUpTelemetry("ruleLookupByDomain", expectedTelemetryOnce);
 
+    Services.cookieBanners.removeAllExecutedRecords(false);
+
     info("Open the same domain again.");
     // Load the same domain again, verify that the telemetry counts increases for
     // load telemetry not not for domain telemetry.
@@ -275,6 +276,9 @@ add_task(async function test_rule_lookup_telemetry() {
   });
   insertTestClickRules();
 
+  // Clear the executed records before testing.
+  Services.cookieBanners.removeAllExecutedRecords(false);
+
   // Open a tab for testing.
   let tab = await BrowserTestUtils.openNewForegroundTab(gBrowser);
 
@@ -345,6 +349,9 @@ add_task(async function test_rule_lookup_telemetry() {
     }
 
     for (let context of ["top", "iframe"]) {
+      // Clear the executed records before testing.
+      Services.cookieBanners.removeAllExecutedRecords(false);
+
       info(`Test in a ${context} context.`);
       let isTop = context === "top";
 
@@ -385,6 +392,8 @@ add_task(async function test_rule_lookup_telemetry() {
       verifyLookUpTelemetry("ruleLookupByLoad", expectedTelemetry);
       verifyLookUpTelemetry("ruleLookupByDomain", expectedTelemetry);
 
+      Services.cookieBanners.removeAllExecutedRecords(false);
+
       info("Load a domain with only opt-in clicking rules");
       await openLookUpTelemetryTestPage(
         tab.linkedBrowser,
@@ -423,6 +432,8 @@ add_task(async function test_rule_lookup_telemetry() {
       verifyLookUpTelemetry("ruleLookupByLoad", expectedTelemetry);
       verifyLookUpTelemetry("ruleLookupByDomain", expectedTelemetry);
 
+      Services.cookieBanners.removeAllExecutedRecords(false);
+
       info(
         "Load a domain again to verify that we don't collect domain telemetry for this time."
       );
@@ -573,7 +584,7 @@ add_task(async function test_reload_telemetry() {
   );
 
   // Load the page with another origin.
-  BrowserTestUtils.loadURIString(tab.linkedBrowser, TEST_ORIGIN_B);
+  BrowserTestUtils.startLoadingURIString(tab.linkedBrowser, TEST_ORIGIN_B);
   await BrowserTestUtils.browserLoaded(tab.linkedBrowser);
 
   // Trigger the reload
@@ -660,7 +671,7 @@ add_task(async function test_reload_telemetry_mode_reject() {
   });
 
   // Load the page with the domain only has opt-in click rule.
-  BrowserTestUtils.loadURIString(tab.linkedBrowser, TEST_ORIGIN_B);
+  BrowserTestUtils.startLoadingURIString(tab.linkedBrowser, TEST_ORIGIN_B);
   await BrowserTestUtils.browserLoaded(tab.linkedBrowser);
 
   // Trigger the reload
