@@ -4,15 +4,17 @@
 "use strict";
 
 // Globals
-const { sinon } = ChromeUtils.import("resource://testing-common/Sinon.jsm");
+const { sinon } = ChromeUtils.importESModule(
+  "resource://testing-common/Sinon.sys.mjs"
+);
 
-XPCOMUtils.defineLazyModuleGetters(this, {
-  ExperimentManager: "resource://nimbus/lib/ExperimentManager.jsm",
-  ExperimentTestUtils: "resource://testing-common/NimbusTestUtils.jsm",
-  ExperimentFakes: "resource://testing-common/NimbusTestUtils.jsm",
+ChromeUtils.defineESModuleGetters(this, {
+  ExperimentManager: "resource://nimbus/lib/ExperimentManager.sys.mjs",
+  ExperimentTestUtils: "resource://testing-common/NimbusTestUtils.sys.mjs",
+  ExperimentFakes: "resource://testing-common/NimbusTestUtils.sys.mjs",
 });
 
-add_setup(function() {
+add_setup(function () {
   let sandbox = sinon.createSandbox();
 
   /* We stub the functions that operate with enrollments and remote rollouts
@@ -25,8 +27,8 @@ add_setup(function() {
   );
   sandbox
     .stub(ExperimentManager.store, "addEnrollment")
-    .callsFake(async enrollment => {
-      await ExperimentTestUtils.validateEnrollment(enrollment);
+    .callsFake(enrollment => {
+      ExperimentTestUtils.validateEnrollment(enrollment);
       return origAddExperiment(enrollment);
     });
 
