@@ -51,7 +51,7 @@ let login2B = new nsLoginInfo(
 
 requestLongerTimeout(2);
 
-add_setup(async function() {
+add_setup(async function () {
   // Load recipes for this test.
   let recipeParent = await LoginManagerParent.recipeParentPromise;
   await recipeParent.load({
@@ -68,7 +68,7 @@ add_setup(async function() {
 add_task(async function test_remember_opens() {
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -90,7 +90,7 @@ add_task(async function test_remember_opens() {
 add_task(async function test_clickNever() {
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -117,46 +117,52 @@ add_task(async function test_clickNever() {
   );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
 
   info("Make sure Never took effect");
-  await testSubmittingLoginFormHTTP("subtst_notifications_1.html", function(
-    fieldValues
-  ) {
-    Assert.equal(
-      fieldValues.username,
-      "notifyu1",
-      "Checking submitted username"
-    );
-    Assert.equal(
-      fieldValues.password,
-      "notifyp1",
-      "Checking submitted password"
-    );
-    let notif = getCaptureDoorhanger("password-save");
-    Assert.ok(!notif, "checking for no notification popup");
-    Assert.equal(
-      false,
-      Services.logins.getLoginSavingEnabled("http://example.com"),
-      "Checking for login saving disabled"
-    );
-    Services.logins.setLoginSavingEnabled("http://example.com", true);
-  });
+  await testSubmittingLoginFormHTTP(
+    "subtst_notifications_1.html",
+    function (fieldValues) {
+      Assert.equal(
+        fieldValues.username,
+        "notifyu1",
+        "Checking submitted username"
+      );
+      Assert.equal(
+        fieldValues.password,
+        "notifyp1",
+        "Checking submitted password"
+      );
+      let notif = getCaptureDoorhanger("password-save");
+      Assert.ok(!notif, "checking for no notification popup");
+      Assert.equal(
+        false,
+        Services.logins.getLoginSavingEnabled("http://example.com"),
+        "Checking for login saving disabled"
+      );
+      Services.logins.setLoginSavingEnabled("http://example.com", true);
+    }
+  );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
 });
 
 add_task(async function test_clickRemember() {
+  const storageChangedPromise = TestUtils.topicObserved(
+    "passwordmgr-storage-changed",
+    (_, data) => data == "addLogin"
+  );
+
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -172,7 +178,7 @@ add_task(async function test_clickRemember() {
       Assert.ok(!notif.dismissed, "doorhanger is not dismissed");
 
       Assert.equal(
-        Services.logins.getAllLogins().length,
+        (await Services.logins.getAllLogins()).length,
         0,
         "Should not have any logins yet"
       );
@@ -180,14 +186,16 @@ add_task(async function test_clickRemember() {
       await checkDoorhangerUsernamePassword("notifyu1", "notifyp1");
       let promiseNewSavedPassword = TestUtils.topicObserved(
         "LoginStats:NewSavedPassword",
-        (subject, data) => subject == gBrowser.selectedBrowser
+        (subject, _topic, _data) => subject == gBrowser.selectedBrowser
       );
       clickDoorhangerButton(notif, REMEMBER_BUTTON);
       await promiseNewSavedPassword;
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  await storageChangedPromise;
+
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(
@@ -205,25 +213,26 @@ add_task(async function test_clickRemember() {
   info(
     "Make sure Remember took effect and we don't prompt for an existing login"
   );
-  await testSubmittingLoginFormHTTP("subtst_notifications_1.html", function(
-    fieldValues
-  ) {
-    // form login matches a saved login, we don't expect a notification on change or submit
-    Assert.equal(
-      fieldValues.username,
-      "notifyu1",
-      "Checking submitted username"
-    );
-    Assert.equal(
-      fieldValues.password,
-      "notifyp1",
-      "Checking submitted password"
-    );
-    let notif = getCaptureDoorhanger("password-save");
-    Assert.ok(!notif, "checking for no notification popup");
-  });
+  await testSubmittingLoginFormHTTP(
+    "subtst_notifications_1.html",
+    function (fieldValues) {
+      // form login matches a saved login, we don't expect a notification on change or submit
+      Assert.equal(
+        fieldValues.username,
+        "notifyu1",
+        "Checking submitted username"
+      );
+      Assert.equal(
+        fieldValues.password,
+        "notifyp1",
+        "Checking submitted password"
+      );
+      let notif = getCaptureDoorhanger("password-save");
+      Assert.ok(!notif, "checking for no notification popup");
+    }
+  );
 
-  logins = Services.logins.getAllLogins();
+  logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username used");
@@ -243,25 +252,26 @@ add_task(async function test_rememberSignonsFalse() {
   info("Make sure we don't prompt with rememberSignons=false");
   Services.prefs.setBoolPref("signon.rememberSignons", false);
 
-  await testSubmittingLoginFormHTTP("subtst_notifications_1.html", function(
-    fieldValues
-  ) {
-    Assert.equal(
-      fieldValues.username,
-      "notifyu1",
-      "Checking submitted username"
-    );
-    Assert.equal(
-      fieldValues.password,
-      "notifyp1",
-      "Checking submitted password"
-    );
-    let notif = getCaptureDoorhanger("password-save");
-    Assert.ok(!notif, "checking for no notification popup");
-  });
+  await testSubmittingLoginFormHTTP(
+    "subtst_notifications_1.html",
+    function (fieldValues) {
+      Assert.equal(
+        fieldValues.username,
+        "notifyu1",
+        "Checking submitted username"
+      );
+      Assert.equal(
+        fieldValues.password,
+        "notifyp1",
+        "Checking submitted password"
+      );
+      let notif = getCaptureDoorhanger("password-save");
+      Assert.ok(!notif, "checking for no notification popup");
+    }
+  );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -273,7 +283,7 @@ add_task(async function test_rememberSignonsTrue() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -292,7 +302,7 @@ add_task(async function test_rememberSignonsTrue() {
   );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -307,7 +317,7 @@ add_task(async function test_autocompleteOffUsername() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_2.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -326,7 +336,7 @@ add_task(async function test_autocompleteOffUsername() {
   );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -339,7 +349,7 @@ add_task(async function test_autocompleteOffPassword() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_3.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -358,7 +368,7 @@ add_task(async function test_autocompleteOffPassword() {
   );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -369,7 +379,7 @@ add_task(async function test_autocompleteOffForm() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_4.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -388,7 +398,7 @@ add_task(async function test_autocompleteOffForm() {
   );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -397,21 +407,22 @@ add_task(async function test_autocompleteOffForm() {
 add_task(async function test_noPasswordField() {
   info("Check for no notification popup when no password field present");
 
-  await testSubmittingLoginFormHTTP("subtst_notifications_5.html", function(
-    fieldValues
-  ) {
-    Assert.equal(
-      fieldValues.username,
-      "notifyu1",
-      "Checking submitted username"
-    );
-    Assert.equal(fieldValues.password, "null", "Checking submitted password");
-    let notif = getCaptureDoorhanger("password-save");
-    Assert.ok(!notif, "checking for no notification popup");
-  });
+  await testSubmittingLoginFormHTTP(
+    "subtst_notifications_5.html",
+    function (fieldValues) {
+      Assert.equal(
+        fieldValues.username,
+        "notifyu1",
+        "Checking submitted username"
+      );
+      Assert.equal(fieldValues.password, "null", "Checking submitted password");
+      let notif = getCaptureDoorhanger("password-save");
+      Assert.ok(!notif, "checking for no notification popup");
+    }
+  );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -419,10 +430,11 @@ add_task(async function test_noPasswordField() {
 
 add_task(async function test_pwOnlyNewLoginMatchesUPForm() {
   info("Check for update popup when new existing pw-only login matches form.");
-  Services.logins.addLogin(login2);
+  await Services.logins.addLoginAsync(login2);
+
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -461,7 +473,7 @@ add_task(async function test_pwOnlyNewLoginMatchesUPForm() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username");
@@ -473,7 +485,7 @@ add_task(async function test_pwOnlyNewLoginMatchesUPForm() {
 
 add_task(async function test_pwOnlyOldLoginMatchesUPForm() {
   info("Check for update popup when old existing pw-only login matches form.");
-  Services.logins.addLogin(login2);
+  await Services.logins.addLoginAsync(login2);
 
   // Change the timePasswordChanged to be old so that the password won't be
   // revealed in the doorhanger.
@@ -489,7 +501,7 @@ add_task(async function test_pwOnlyOldLoginMatchesUPForm() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -528,7 +540,7 @@ add_task(async function test_pwOnlyOldLoginMatchesUPForm() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username");
@@ -542,22 +554,23 @@ add_task(async function test_pwOnlyFormMatchesLogin() {
   info(
     "Check for no notification popup when pw-only form matches existing login."
   );
-  Services.logins.addLogin(login1);
+  await Services.logins.addLoginAsync(login1);
 
-  await testSubmittingLoginFormHTTP("subtst_notifications_6.html", function(
-    fieldValues
-  ) {
-    Assert.equal(fieldValues.username, "null", "Checking submitted username");
-    Assert.equal(
-      fieldValues.password,
-      "notifyp1",
-      "Checking submitted password"
-    );
-    let notif = getCaptureDoorhanger("password-save");
-    Assert.ok(!notif, "checking for no notification popup");
-  });
+  await testSubmittingLoginFormHTTP(
+    "subtst_notifications_6.html",
+    function (fieldValues) {
+      Assert.equal(fieldValues.username, "null", "Checking submitted username");
+      Assert.equal(
+        fieldValues.password,
+        "notifyp1",
+        "Checking submitted password"
+      );
+      let notif = getCaptureDoorhanger("password-save");
+      Assert.ok(!notif, "checking for no notification popup");
+    }
+  );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username");
@@ -571,11 +584,11 @@ add_task(async function test_pwOnlyFormDoesntMatchExisting() {
   info(
     "Check for notification popup when pw-only form doesn't match existing login."
   );
-  Services.logins.addLogin(login1B);
+  await Services.logins.addLoginAsync(login1B);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_6.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(fieldValues.username, "null", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -589,7 +602,7 @@ add_task(async function test_pwOnlyFormDoesntMatchExisting() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1B", "Check the username unchanged");
@@ -601,11 +614,11 @@ add_task(async function test_pwOnlyFormDoesntMatchExisting() {
 
 add_task(async function test_changeUPLoginOnUPForm_dont() {
   info("Check for change-password popup, u+p login on u+p form. (not changed)");
-  Services.logins.addLogin(login1);
+  await Services.logins.addLoginAsync(login1);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_8.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -621,7 +634,7 @@ add_task(async function test_changeUPLoginOnUPForm_dont() {
       Assert.ok(!notif.dismissed, "doorhanger is not dismissed");
       Assert.equal(
         notif.message,
-        "Update login for example.com?",
+        "Update password for example.com?",
         "Check message"
       );
 
@@ -630,7 +643,7 @@ add_task(async function test_changeUPLoginOnUPForm_dont() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username unchanged");
@@ -642,11 +655,11 @@ add_task(async function test_changeUPLoginOnUPForm_dont() {
 
 add_task(async function test_changeUPLoginOnUPForm_remove() {
   info("Check for change-password popup, u+p login on u+p form. (remove)");
-  Services.logins.addLogin(login1);
+  await Services.logins.addLoginAsync(login1);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_8.html",
-    async function(fieldValues, browser) {
+    async function (fieldValues, browser) {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -662,7 +675,7 @@ add_task(async function test_changeUPLoginOnUPForm_remove() {
       Assert.ok(!notif.dismissed, "doorhanger is not dismissed");
       Assert.equal(
         notif.message,
-        "Update login for example.com?",
+        "Update password for example.com?",
         "Check message"
       );
 
@@ -673,21 +686,25 @@ add_task(async function test_changeUPLoginOnUPForm_remove() {
       const forceClosePopup = false;
       // Make sure confirmation hint was shown
       info("waiting for verifyConfirmationHint");
-      await verifyConfirmationHint(browser, forceClosePopup, "identity-icon");
+      await verifyConfirmationHint(
+        browser,
+        forceClosePopup,
+        "identity-icon-box"
+      );
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 0, "Should have 0 logins");
 });
 
 add_task(async function test_changeUPLoginOnUPForm_change() {
   info("Check for change-password popup, u+p login on u+p form.");
-  Services.logins.addLogin(login1);
+  await Services.logins.addLoginAsync(login1);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_8.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -703,14 +720,14 @@ add_task(async function test_changeUPLoginOnUPForm_change() {
       Assert.ok(!notif.dismissed, "doorhanger is not dismissed");
       Assert.equal(
         notif.message,
-        "Update login for example.com?",
+        "Update password for example.com?",
         "Check message"
       );
 
       await checkDoorhangerUsernamePassword("notifyu1", "pass2");
       let promiseLoginUpdateSaved = TestUtils.topicObserved(
         "LoginStats:LoginUpdateSaved",
-        (subject, data) => subject == gBrowser.selectedBrowser
+        (subject, _topic, _data) => subject == gBrowser.selectedBrowser
       );
       clickDoorhangerButton(notif, CHANGE_BUTTON);
       await promiseLoginUpdateSaved;
@@ -722,14 +739,14 @@ add_task(async function test_changeUPLoginOnUPForm_change() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username unchanged");
   Assert.equal(login.password, "pass2", "Check the password changed");
   Assert.equal(login.timesUsed, 2, "Check times used");
 
-  checkOnlyLoginWasUsedTwice({ justChanged: true });
+  await checkOnlyLoginWasUsedTwice({ justChanged: true });
 
   // cleanup
   login1.password = "pass2";
@@ -739,11 +756,11 @@ add_task(async function test_changeUPLoginOnUPForm_change() {
 
 add_task(async function test_changePLoginOnUPForm() {
   info("Check for change-password popup, p-only login on u+p form (empty u).");
-  Services.logins.addLogin(login2);
+  await Services.logins.addLoginAsync(login2);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_9.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(fieldValues.username, "", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -769,7 +786,7 @@ add_task(async function test_changePLoginOnUPForm() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "", "Check the username unchanged");
@@ -784,7 +801,7 @@ add_task(async function test_changePLoginOnPForm() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_10.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(fieldValues.username, "null", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -810,7 +827,7 @@ add_task(async function test_changePLoginOnPForm() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "", "Check the username unchanged");
@@ -825,7 +842,7 @@ add_task(async function test_checkUPSaveText() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -841,7 +858,7 @@ add_task(async function test_checkUPSaveText() {
       Assert.ok(notif, "got notification popup");
       // Check the text, which comes from the localized saveLoginMsg string.
       let notificationText = notif.message;
-      let expectedText = "Save login for example.com?";
+      let expectedText = "Save password for example.com?";
       Assert.equal(
         notificationText,
         expectedText,
@@ -852,7 +869,7 @@ add_task(async function test_checkUPSaveText() {
   );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -863,7 +880,7 @@ add_task(async function test_checkPSaveText() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_6.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(fieldValues.username, "null", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -886,7 +903,7 @@ add_task(async function test_checkPSaveText() {
   );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -900,7 +917,7 @@ add_task(async function test_capture2pw0un() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_2pw_0un.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(fieldValues.username, "null", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -915,7 +932,7 @@ add_task(async function test_capture2pw0un() {
   );
 
   Assert.equal(
-    Services.logins.getAllLogins().length,
+    (await Services.logins.getAllLogins()).length,
     0,
     "Should not have any logins yet"
   );
@@ -927,11 +944,11 @@ add_task(async function test_change2pw0unExistingDifferentUP() {
       "is submitted and there is a saved login with a username and different password."
   );
 
-  Services.logins.addLogin(login1B);
+  await Services.logins.addLoginAsync(login1B);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_2pw_0un.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(fieldValues.username, "null", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -945,7 +962,7 @@ add_task(async function test_change2pw0unExistingDifferentUP() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1B", "Check the username unchanged");
@@ -961,11 +978,11 @@ add_task(async function test_change2pw0unExistingDifferentP() {
       "is submitted and there is a saved login with no username and different password."
   );
 
-  Services.logins.addLogin(login2B);
+  await Services.logins.addLoginAsync(login2B);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_2pw_0un.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(fieldValues.username, "null", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -979,7 +996,7 @@ add_task(async function test_change2pw0unExistingDifferentP() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "", "Check the username unchanged");
@@ -995,11 +1012,11 @@ add_task(async function test_change2pw0unExistingWithSameP() {
       "is submitted and there is a saved login with a username and the same password."
   );
 
-  Services.logins.addLogin(login2);
+  await Services.logins.addLoginAsync(login2);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_2pw_0un.html",
-    function(fieldValues) {
+    function (fieldValues) {
       Assert.equal(fieldValues.username, "null", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -1011,25 +1028,25 @@ add_task(async function test_change2pw0unExistingWithSameP() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "", "Check the username unchanged");
   Assert.equal(login.password, "notifyp1", "Check the password unchanged");
   Assert.equal(login.timesUsed, 2, "Check times used incremented");
 
-  checkOnlyLoginWasUsedTwice({ justChanged: false });
+  await checkOnlyLoginWasUsedTwice({ justChanged: false });
 
   Services.logins.removeLogin(login2);
 });
 
 add_task(async function test_changeUPLoginOnPUpdateForm() {
   info("Check for change-password popup, u+p login on password update form.");
-  Services.logins.addLogin(login1);
+  await Services.logins.addLoginAsync(login1);
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_change_p.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(fieldValues.username, "null", "Checking submitted username");
       Assert.equal(
         fieldValues.password,
@@ -1050,14 +1067,14 @@ add_task(async function test_changeUPLoginOnPUpdateForm() {
     }
   );
 
-  let logins = Services.logins.getAllLogins();
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username unchanged");
   Assert.equal(login.password, "pass2", "Check the password changed");
   Assert.equal(login.timesUsed, 2, "Check times used");
 
-  checkOnlyLoginWasUsedTwice({ justChanged: true });
+  await checkOnlyLoginWasUsedTwice({ justChanged: true });
 
   // cleanup
   login1.password = "pass2";
@@ -1070,9 +1087,14 @@ add_task(async function test_recipeCaptureFields_NewLogin() {
     "Check that we capture the proper fields when a field recipe is in use."
   );
 
+  const storageChangedPromise = TestUtils.topicObserved(
+    "passwordmgr-storage-changed",
+    (_, data) => data == "addLogin"
+  );
+
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_2pw_1un_1text.html",
-    async function(fieldValues) {
+    async fieldValues => {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -1088,7 +1110,7 @@ add_task(async function test_recipeCaptureFields_NewLogin() {
       Assert.ok(!notif.dismissed, "doorhanger is not dismissed");
 
       // Sanity check, no logins should exist yet.
-      let logins = Services.logins.getAllLogins();
+      let logins = await Services.logins.getAllLogins();
       Assert.equal(logins.length, 0, "Should not have any logins yet");
 
       await checkDoorhangerUsernamePassword("notifyu1", "notifyp1");
@@ -1097,7 +1119,9 @@ add_task(async function test_recipeCaptureFields_NewLogin() {
     "http://example.org"
   ); // The recipe is for example.org
 
-  let logins = Services.logins.getAllLogins();
+  await storageChangedPromise;
+
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username unchanged");
@@ -1113,7 +1137,7 @@ add_task(async function test_recipeCaptureFields_ExistingLogin() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_2pw_1un_1text.html",
-    function(fieldValues) {
+    function (fieldValues) {
       Assert.equal(
         fieldValues.username,
         "notifyu1",
@@ -1130,8 +1154,8 @@ add_task(async function test_recipeCaptureFields_ExistingLogin() {
     "http://example.org"
   );
 
-  checkOnlyLoginWasUsedTwice({ justChanged: false });
-  let logins = Services.logins.getAllLogins();
+  await checkOnlyLoginWasUsedTwice({ justChanged: false });
+  let logins = await Services.logins.getAllLogins();
   Assert.equal(logins.length, 1, "Should only have 1 login");
   let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
   Assert.equal(login.username, "notifyu1", "Check the username unchanged");
@@ -1143,7 +1167,7 @@ add_task(async function test_recipeCaptureFields_ExistingLogin() {
 
 add_task(async function test_saveUsingEnter() {
   async function testWithTextboxSelector(fieldSelector) {
-    let storageChangedPromise = TestUtils.topicObserved(
+    const storageChangedPromise = TestUtils.topicObserved(
       "passwordmgr-storage-changed",
       (_, data) => data == "addLogin"
     );
@@ -1151,7 +1175,7 @@ add_task(async function test_saveUsingEnter() {
     info("Waiting for form submit and doorhanger interaction");
     await testSubmittingLoginFormHTTP(
       "subtst_notifications_1.html",
-      async function(fieldValues) {
+      async fieldValues => {
         Assert.equal(
           fieldValues.username,
           "notifyu1",
@@ -1166,7 +1190,7 @@ add_task(async function test_saveUsingEnter() {
         Assert.ok(notif, "got notification popup");
         Assert.ok(!notif.dismissed, "doorhanger is not dismissed");
         Assert.equal(
-          Services.logins.getAllLogins().length,
+          (await Services.logins.getAllLogins()).length,
           0,
           "Should not have any logins yet"
         );
@@ -1177,9 +1201,10 @@ add_task(async function test_saveUsingEnter() {
         await EventUtils.synthesizeKey("KEY_Enter");
       }
     );
+
     await storageChangedPromise;
 
-    let logins = Services.logins.getAllLogins();
+    let logins = await Services.logins.getAllLogins();
     Assert.equal(logins.length, 1, "Should only have 1 login");
     let login = logins[0].QueryInterface(Ci.nsILoginMetaInfo);
     Assert.equal(
@@ -1206,7 +1231,7 @@ add_task(async function test_noShowPasswordOnDismissal() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async function (_fieldValues) {
       info("Opening popup");
       let notif = await getCaptureDoorhangerThatMayOpen("password-save");
       Assert.ok(!notif.dismissed, "doorhanger is not dismissed");
@@ -1240,7 +1265,7 @@ add_task(async function test_showPasswordOn1stOpenOfDismissedByDefault() {
 
   await testSubmittingLoginFormHTTP(
     "subtst_notifications_1.html",
-    async function(fieldValues) {
+    async function (_fieldValues) {
       info("Opening popup");
       let notif = await getCaptureDoorhangerThatMayOpen("password-save");
       Assert.ok(!notif.dismissed, "doorhanger is not dismissed");
