@@ -1,11 +1,15 @@
 /* eslint max-len: ["error", 80] */
 
-const { AddonTestUtils } = ChromeUtils.import(
-  "resource://testing-common/AddonTestUtils.jsm"
+const { AddonTestUtils } = ChromeUtils.importESModule(
+  "resource://testing-common/AddonTestUtils.sys.mjs"
 );
-const { ExtensionPermissions } = ChromeUtils.import(
-  "resource://gre/modules/ExtensionPermissions.jsm"
+const { ExtensionPermissions } = ChromeUtils.importESModule(
+  "resource://gre/modules/ExtensionPermissions.sys.mjs"
 );
+const { PERMISSION_L10N, PERMISSION_L10N_ID_OVERRIDES } =
+  ChromeUtils.importESModule(
+    "resource://gre/modules/ExtensionPermissionMessages.sys.mjs"
+  );
 
 AddonTestUtils.initMochitest(this);
 
@@ -274,8 +278,9 @@ async function runTest(options) {
       perms = enabled ? perms.removed : perms.added;
     }
 
-    ok(
-      perms.permissions.length + perms.origins.length > 0,
+    Assert.greater(
+      perms.permissions.length + perms.origins.length,
+      0,
       "Some permission(s) toggled."
     );
 
@@ -414,7 +419,11 @@ async function runTest(options) {
   }
 }
 
-async function testPermissionsView({ manifestV3enabled, manifest_version }) {
+async function testPermissionsView({
+  manifestV3enabled,
+  manifest_version,
+  expectGranted,
+}) {
   await SpecialPowers.pushPrefEnv({
     set: [["extensions.manifestV3.enabled", manifestV3enabled]],
   });
@@ -433,7 +442,16 @@ async function testPermissionsView({ manifestV3enabled, manifest_version }) {
       extension: extensions["addon1@mochi.test"],
       permissions: ["<all_urls>", "tabs", "webNavigation"],
     });
-  } else {
+  }
+  if (manifest_version >= 3 && expectGranted) {
+    await runTest({
+      extension: extensions["addon1@mochi.test"],
+      permissions: ["tabs", "webNavigation"],
+      optional_permissions: ["<all_urls>"],
+      optional_enabled: ["<all_urls>"],
+    });
+  }
+  if (manifest_version >= 3 && !expectGranted) {
     await runTest({
       extension: extensions["addon1@mochi.test"],
       permissions: ["tabs", "webNavigation"],
@@ -539,8 +557,28 @@ add_task(async function testPermissionsView_MV2_manifestV3enabled() {
   await testPermissionsView({ manifestV3enabled: true, manifest_version: 2 });
 });
 
+add_task(async function testPermissionsView_MV3_noInstallPrompt() {
+  await SpecialPowers.pushPrefEnv({
+    set: [["extensions.originControls.grantByDefault", false]],
+  });
+  await testPermissionsView({
+    manifestV3enabled: true,
+    manifest_version: 3,
+    expectGranted: false,
+  });
+  await SpecialPowers.popPrefEnv();
+});
+
 add_task(async function testPermissionsView_MV3() {
-  await testPermissionsView({ manifestV3enabled: true, manifest_version: 3 });
+  await SpecialPowers.pushPrefEnv({
+    set: [["extensions.originControls.grantByDefault", true]],
+  });
+  await testPermissionsView({
+    manifestV3enabled: true,
+    manifest_version: 3,
+    expectGranted: true,
+  });
+  await SpecialPowers.popPrefEnv();
 });
 
 add_task(async function testPermissionsViewStates() {
@@ -608,7 +646,7 @@ add_task(async function testPermissionsViewStates() {
   let card = getAddonCard(view, addon.id);
   await Assert.rejects(
     card.setAddonPermission("webRequest", "permission", "add"),
-    /permission missing from manifest/,
+    /was not declared in optional_permissions/,
     "unable to set the addon permission"
   );
 
@@ -618,7 +656,10 @@ add_task(async function testPermissionsViewStates() {
 
 add_task(async function testAllUrlsNotGrantedUnconditionally_MV3() {
   await SpecialPowers.pushPrefEnv({
-    set: [["extensions.manifestV3.enabled", true]],
+    set: [
+      ["extensions.manifestV3.enabled", true],
+      ["extensions.originControls.grantByDefault", false],
+    ],
   });
 
   const extension = ExtensionTestUtils.loadExtension({
@@ -728,3 +769,95 @@ add_task(async function test_OneOfMany_AllSites_toggle() {
   await extension.unload();
   /* eslint-enable @microsoft/sdl/no-insecure-url */
 });
+
+add_task(async function testOverrideLocalization() {
+  // Mock a fluent file.
+  const l10nReg = L10nRegistry.getInstance();
+  const source = L10nFileSource.createMock(
+    "mock",
+    "app",
+    ["en-US"],
+    "/localization/",
+    [
+      {
+        path: "/localization/mock.ftl",
+        source: `
+webext-perms-description-test-tabs = Custom description for the tabs permission
+`,
+      },
+    ]
+  );
+  l10nReg.registerSources([source]);
+
+  // Add the mocked fluent file to PERMISSION_L10N and override the tabs
+  // permission to use the alternative string. In a real world use-case, this
+  // would be used to add non-toolkit fluent files with permission strings of
+  // APIs which are defined outside of toolkit.
+  PERMISSION_L10N.addResourceIds(["mock.ftl"]);
+  PERMISSION_L10N_ID_OVERRIDES.set(
+    "tabs",
+    "webext-perms-description-test-tabs"
+  );
+
+  let mockCleanup = () => {
+    // Make sure cleanup is executed only once.
+    mockCleanup = () => {};
+
+    // Remove the non-toolkit permission string.
+    PERMISSION_L10N.removeResourceIds(["mock.ftl"]);
+    PERMISSION_L10N_ID_OVERRIDES.delete("tabs");
+    l10nReg.removeSources(["mock"]);
+  };
+  registerCleanupFunction(mockCleanup);
+
+  // Load an example add-on which uses the tabs permission.
+  let extension = ExtensionTestUtils.loadExtension({
+    manifest: {
+      manifest_version: 2,
+      name: "Simple test add-on",
+      browser_specific_settings: { gecko: { id: "testAddon@mochi.test" } },
+      permissions: ["tabs"],
+    },
+    background,
+    useAddonManager: "temporary",
+  });
+  await extension.startup();
+  let addonId = extension.id;
+
+  let win = await loadInitialView("extension");
+
+  // Open the card and navigate to its permission list.
+  let card = getAddonCard(win, addonId);
+  let permsSection = card.querySelector("addon-permissions-list");
+  if (!permsSection) {
+    ok(!card.hasAttribute("expanded"), "The list card is not expanded");
+    let loaded = waitForViewLoad(win);
+    card.querySelector('[action="expand"]').click();
+    await loaded;
+  }
+
+  card = getAddonCard(win, addonId);
+  let { deck, tabGroup } = card.details;
+
+  let permsBtn = tabGroup.querySelector('[name="permissions"]');
+  let permsShown = BrowserTestUtils.waitForEvent(deck, "view-changed");
+  permsBtn.click();
+  await permsShown;
+  let permissionList = card.querySelector("addon-permissions-list");
+  let permissionEntries = Array.from(permissionList.querySelectorAll("li"));
+  Assert.equal(
+    permissionEntries.length,
+    1,
+    "Should find a single permission entry"
+  );
+  Assert.equal(
+    permissionEntries[0].textContent,
+    "Custom description for the tabs permission",
+    "Should find the non-default permission description"
+  );
+
+  await closeView(win);
+  await extension.unload();
+
+  mockCleanup();
+});
