@@ -1,10 +1,10 @@
 /* eslint max-len: ["error", 80] */
 
-const { AddonTestUtils } = ChromeUtils.import(
-  "resource://testing-common/AddonTestUtils.jsm"
+const { AddonTestUtils } = ChromeUtils.importESModule(
+  "resource://testing-common/AddonTestUtils.sys.mjs"
 );
-const { ExtensionParent } = ChromeUtils.import(
-  "resource://gre/modules/ExtensionParent.jsm"
+const { ExtensionParent } = ChromeUtils.importESModule(
+  "resource://gre/modules/ExtensionParent.sys.mjs"
 );
 
 AddonTestUtils.initMochitest(this);
@@ -115,13 +115,7 @@ add_task(async function testInlineOptions() {
     "The browser has the expected options URL"
   );
   is(url, card.addon.optionsURL, "Browser has the expected options URL loaded");
-  let stack = browser.closest("stack");
-  is(
-    browser.clientWidth,
-    stack.clientWidth,
-    "Browser should be the same width as its direct parent"
-  );
-  ok(stack.clientWidth > 0, "The stack has a width");
+  Assert.greater(browser.clientWidth, 0, "The browser has a width");
   ok(
     card.querySelector('[action="preferences"]').hidden,
     "The preferences option is hidden now"
@@ -163,8 +157,7 @@ add_task(async function testInlineOptions() {
   info("Switch back, check browser is shown");
   prefsBtn.click();
 
-  is(browser.clientWidth, stack.clientWidth, "The browser width is set again");
-  ok(stack.clientWidth > 0, "The stack has a width");
+  Assert.greater(browser.clientWidth, 0, "The browser has a width");
 
   await closeView(win);
   await extension.unload();
@@ -298,9 +291,7 @@ add_task(async function testRemovedOnDisable() {
 
   // Opens the prefs page.
   let loaded = waitForViewLoad(win);
-  getAddonCard(win, id)
-    .querySelector("[action=preferences]")
-    .click();
+  getAddonCard(win, id).querySelector("[action=preferences]").click();
   await loaded;
 
   let inlineOptions = doc.querySelector("inline-options-browser");
@@ -473,6 +464,22 @@ add_task(async function testReloadExtension() {
   await addon.uninstall();
 });
 
+async function testSelectPosition(optionsBrowser, zoom) {
+  let popupShownPromise = BrowserTestUtils.waitForSelectPopupShown(window);
+  await BrowserTestUtils.synthesizeMouseAtCenter("select", {}, optionsBrowser);
+  let popup = await popupShownPromise;
+  let popupLeft = popup.shadowRoot.querySelector(
+    ".menupopup-arrowscrollbox"
+  ).screenX;
+  let browserLeft = optionsBrowser.screenX * zoom;
+  Assert.lessOrEqual(
+    Math.abs(popupLeft - browserLeft),
+    1,
+    `Popup should be correctly positioned: ${popupLeft} vs. ${browserLeft}`
+  );
+  popup.hidePopup();
+}
+
 async function testOptionsZoom(type = "full") {
   let id = `${type}-zoom@mochi.test`;
   let zoomProp = `${type}Zoom`;
@@ -485,12 +492,23 @@ async function testOptionsZoom(type = "full") {
     },
     files: {
       "options.html": `
-        <html>
-          <body>
-            <p>Some text</p>
-          </body>
-        </html>
+        <!doctype html>
+        <script src="options.js"></script>
+        <body style="height: 500px">
+          <p>Some text</p>
+          <p>
+            <select>
+              <option>A</option>
+              <option>B</option>
+            </select>
+          </p>
+        </body>
       `,
+      "options.js": () => {
+        window.addEventListener("load", function () {
+          browser.test.sendMessage("options-loaded");
+        });
+      },
     },
     useAddonManager: "permanent",
   });
@@ -511,9 +529,13 @@ async function testOptionsZoom(type = "full") {
   let browserAdded = waitOptionsBrowserInserted();
   card.querySelector('.tab-button[name="preferences"]').click();
   let optionsBrowser = await browserAdded;
+  // Wait for the browser to load.
+  await extension.awaitMessage("options-loaded");
 
   is(optionsBrowser[zoomProp], 2, `Options browser inherited ${zoomProp}`);
 
+  await testSelectPosition(optionsBrowser, type == "full" ? 2 : 1);
+
   gBrowser.selectedBrowser[zoomProp] = 0.5;
 
   is(
