@@ -1,12 +1,17 @@
 // ----------------------------------------------------------------------------
 // Test whether an install succeeds when a valid hash is included
 // This verifies bug 302284
-function test() {
+add_task(async function test_install_with_hash() {
   // This test currently depends on InstallTrigger.install availability.
   setInstallTriggerPrefs();
 
-  Harness.installEndedCallback = install_ended;
-  Harness.installsCompletedCallback = finish_test;
+  const xpiFilePath = getTestFilePath("./amosigned.xpi");
+  const xpiFileHash = await IOUtils.computeHexDigest(xpiFilePath, "sha256");
+
+  const deferredInstallCompleted = Promise.withResolvers();
+
+  Harness.installEndedCallback = (install, addon) => addon.uninstall();
+  Harness.installsCompletedCallback = deferredInstallCompleted.resolve;
   Harness.setup();
 
   PermissionTestUtils.add(
@@ -19,7 +24,7 @@ function test() {
     JSON.stringify({
       "Unsigned XPI": {
         URL: TESTROOT + "amosigned.xpi",
-        Hash: "sha1:ee95834ad862245a9ef99ccecc2a857cadc16404",
+        Hash: `sha256:${xpiFileHash}`,
         toString() {
           return this.URL;
         },
@@ -27,21 +32,17 @@ function test() {
     })
   );
   gBrowser.selectedTab = BrowserTestUtils.addTab(gBrowser);
-  BrowserTestUtils.loadURIString(
+  BrowserTestUtils.startLoadingURIString(
     gBrowser,
     TESTROOT + "installtrigger.html?" + triggers
   );
-}
 
-function install_ended(install, addon) {
-  return addon.uninstall();
-}
-
-function finish_test(count) {
+  info("Wait for the install to be completed");
+  const count = await deferredInstallCompleted.promise;
   is(count, 1, "1 Add-on should have been successfully installed");
 
   PermissionTestUtils.remove("http://example.com", "install");
 
   gBrowser.removeCurrentTab();
   Harness.finish();
-}
+});
