@@ -5,19 +5,11 @@
 
 ChromeUtils.defineESModuleGetters(this, {
   AppMenuNotifications: "resource://gre/modules/AppMenuNotifications.sys.mjs",
+  DownloadUtils: "resource://gre/modules/DownloadUtils.sys.mjs",
+  UpdateListener: "resource://gre/modules/UpdateListener.sys.mjs",
 });
-ChromeUtils.defineModuleGetter(
-  this,
-  "DownloadUtils",
-  "resource://gre/modules/DownloadUtils.jsm"
-);
-ChromeUtils.defineModuleGetter(
-  this,
-  "UpdateListener",
-  "resource://gre/modules/UpdateListener.jsm"
-);
-const { XPIInstall } = ChromeUtils.import(
-  "resource://gre/modules/addons/XPIInstall.jsm"
+const { XPIExports } = ChromeUtils.importESModule(
+  "resource://gre/modules/addons/XPIExports.sys.mjs"
 );
 
 const BIN_SUFFIX = AppConstants.platform == "win" ? ".exe" : "";
@@ -151,14 +143,17 @@ registerCleanupFunction(async () => {
  * or reject the install.
  */
 function mockLangpackInstall() {
-  let original = XPIInstall.stageLangpacksForAppUpdate;
+  let original = XPIExports.XPIInstall.stageLangpacksForAppUpdate;
   registerCleanupFunction(() => {
-    XPIInstall.stageLangpacksForAppUpdate = original;
+    XPIExports.XPIInstall.stageLangpacksForAppUpdate = original;
   });
 
-  let stagingCall = PromiseUtils.defer();
-  XPIInstall.stageLangpacksForAppUpdate = (appVersion, platformVersion) => {
-    let result = PromiseUtils.defer();
+  let stagingCall = Promise.withResolvers();
+  XPIExports.XPIInstall.stageLangpacksForAppUpdate = (
+    appVersion,
+    platformVersion
+  ) => {
+    let result = Promise.withResolvers();
     stagingCall.resolve({
       appVersion,
       platformVersion,
@@ -271,7 +266,7 @@ async function setAppUpdateAutoEnabledHelper(enabled) {
  * @param  notificationId
  *         The ID of the notification to get the button for.
  * @param  button
- *         The anonid of the button to get.
+ *         The anonid of the button to get, or a function to find it.
  * @return The button element.
  */
 function getNotificationButton(win, notificationId, button) {
@@ -279,6 +274,9 @@ function getNotificationButton(win, notificationId, button) {
     `appMenu-${notificationId}-notification`
   );
   ok(!notification.hidden, `${notificationId} notification is showing`);
+  if (typeof button === "function") {
+    return button(notification);
+  }
   return notification[button];
 }
 
@@ -289,7 +287,7 @@ function getNotificationButton(win, notificationId, button) {
  * called to continue the setup of the test updater.
  */
 function setupTestUpdater() {
-  return (async function() {
+  return (async function () {
     if (Services.prefs.getBoolPref(PREF_APP_UPDATE_STAGING_ENABLED)) {
       try {
         restoreUpdaterBackup();
@@ -314,7 +312,7 @@ function setupTestUpdater() {
  * copyTestUpdater to continue the setup of the test updater.
  */
 function moveRealUpdater() {
-  return (async function() {
+  return (async function () {
     try {
       // Move away the real updater
       let greBinDir = getGREBinDir();
@@ -354,7 +352,7 @@ function moveRealUpdater() {
  * at times leave the file in use.
  */
 function copyTestUpdater(attempt = 0) {
-  return (async function() {
+  return (async function () {
     try {
       // Copy the test updater
       let greBinDir = getGREBinDir();
@@ -370,9 +368,15 @@ function copyTestUpdater(attempt = 0) {
       testUpdater.copyToFollowingLinks(greBinDir, FILE_UPDATER_BIN);
 
       let greDir = getGREDir();
-      let updateSettingsIni = greDir.clone();
-      updateSettingsIni.append(FILE_UPDATE_SETTINGS_INI);
-      writeFile(updateSettingsIni, UPDATE_SETTINGS_CONTENTS);
+
+      // On macOS, update settings is a Framework, not an INI. This was already
+      // built into updater-xpcshell using the `UpdateSettings-xpcshell`
+      // Framework, so we don't need to do any additional work here.
+      if (AppConstants.platform != "macosx") {
+        let updateSettingsIni = greDir.clone();
+        updateSettingsIni.append(FILE_UPDATE_SETTINGS_INI);
+        writeFile(updateSettingsIni, UPDATE_SETTINGS_CONTENTS);
+      }
 
       let precomplete = greDir.clone();
       precomplete.append(FILE_PRECOMPLETE);
@@ -444,7 +448,7 @@ function restoreUpdaterBackup() {
  * and the other files for the updater if a backup of the file exists.
  */
 function finishTestRestoreUpdaterBackup() {
-  return (async function() {
+  return (async function () {
     try {
       // Windows debug builds keep the updater file in use for a short period of
       // time after the updater process exits.
@@ -489,7 +493,7 @@ function waitForAboutDialog() {
         var domwindow = aXULWindow.docShell.domWindow;
         domwindow.addEventListener("load", aboutDialogOnLoad, true);
       },
-      onCloseWindow: aXULWindow => {},
+      onCloseWindow: _aXULWindow => {},
     };
 
     Services.wm.addListener(listener);
@@ -542,7 +546,7 @@ function runDoorhangerUpdateTest(params, steps) {
       pageURLs,
       expectedStateOverride,
     } = step;
-    return (async function() {
+    return (async function () {
       if (!params.popupShown && !PanelUI.isNotificationPanelOpen) {
         await BrowserTestUtils.waitForEvent(
           PanelUI.notificationPanel,
@@ -605,7 +609,7 @@ function runDoorhangerUpdateTest(params, steps) {
     })();
   }
 
-  return (async function() {
+  return (async function () {
     if (params.slowStaging) {
       Services.env.set("MOZ_TEST_SLOW_SKIP_UPDATE_STAGE", "1");
     } else {
@@ -636,7 +640,7 @@ function runDoorhangerUpdateTest(params, steps) {
     if (params.checkAttempts) {
       // Perform a background check doorhanger test.
       executeSoon(() => {
-        (async function() {
+        (async function () {
           gAUS.checkForBackgroundUpdates();
           for (var i = 0; i < params.checkAttempts - 1; i++) {
             await waitForEvent("update-error", "check-attempt-failed");
@@ -685,7 +689,7 @@ function runAboutDialogUpdateTest(params, steps) {
       noContinue,
       expectedStateOverride,
     } = step;
-    return (async function() {
+    return (async function () {
       await TestUtils.waitForCondition(
         () =>
           aboutDialog.gAppUpdater &&
@@ -701,7 +705,7 @@ function runAboutDialogUpdateTest(params, steps) {
       let { selectedPanel } = aboutDialog.gAppUpdater;
       is(selectedPanel.id, panelId, "The panel ID should equal " + panelId);
       ok(
-        BrowserTestUtils.is_visible(selectedPanel),
+        BrowserTestUtils.isVisible(selectedPanel),
         "The panel should be visible"
       );
 
@@ -720,7 +724,7 @@ function runAboutDialogUpdateTest(params, steps) {
         selectedPanel = aboutDialog.gAppUpdater.selectedPanel;
         is(selectedPanel.id, panelId, "The panel ID should equal " + panelId);
         ok(
-          BrowserTestUtils.is_visible(selectedPanel),
+          BrowserTestUtils.isVisible(selectedPanel),
           "The panel should be visible"
         );
       }
@@ -812,8 +816,16 @@ function runAboutDialogUpdateTest(params, steps) {
               expectedText,
               "Sanity check: Expected download status text should be non-empty"
             );
+            if (aboutDialog.document.hasPendingL10nMutations) {
+              await BrowserTestUtils.waitForEvent(
+                aboutDialog.document,
+                "L10nMutationsFinished"
+              );
+            }
             Assert.equal(
-              aboutDialog.document.getElementById("downloadStatus").textContent,
+              aboutDialog.document.querySelector(
+                `#downloading label[data-l10n-name="download-status"]`
+              ).textContent,
               expectedText,
               "Download status text should be correct"
             );
@@ -823,17 +835,43 @@ function runAboutDialogUpdateTest(params, steps) {
         await continueFileHandler(continueFile);
       }
 
-      let linkPanels = ["downloadFailed", "manualUpdate", "unsupportedSystem"];
+      let linkPanels = [
+        "downloadFailed",
+        "manualUpdate",
+        "unsupportedSystem",
+        "internalError",
+      ];
       if (linkPanels.includes(panelId)) {
         // The unsupportedSystem panel uses the update's detailsURL and the
         // downloadFailed and manualUpdate panels use the app.update.url.manual
         // preference.
-        let link = selectedPanel.querySelector("label.text-link");
+        let selector = "label.text-link";
+        if (selectedPanel.ownerDocument.hasPendingL10nMutations) {
+          await BrowserTestUtils.waitForEvent(
+            selectedPanel.ownerDocument,
+            "L10nMutationsFinished"
+          );
+        }
+        let link = selectedPanel.querySelector(selector);
         is(
           link.href,
           gDetailsURL,
           `The panel's link href should equal ${gDetailsURL}`
         );
+        const assertNonEmptyText = (node, description) => {
+          let textContent = node.textContent.trim();
+          ok(textContent, `${description}, got "${textContent}"`);
+        };
+        assertNonEmptyText(
+          link,
+          `The panel's link should have non-empty textContent`
+        );
+        let linkWrapperClone = link.parentNode.cloneNode(true);
+        linkWrapperClone.querySelector(selector).remove();
+        assertNonEmptyText(
+          linkWrapperClone,
+          `The panel's link should have text around the link`
+        );
       }
 
       // Automatically click the download button unless `noContinue` was passed.
@@ -854,7 +892,7 @@ function runAboutDialogUpdateTest(params, steps) {
     })();
   }
 
-  return (async function() {
+  return (async function () {
     Services.env.set("MOZ_TEST_SLOW_SKIP_UPDATE_STAGE", "1");
     await SpecialPowers.pushPrefEnv({
       set: [
@@ -948,7 +986,7 @@ function runAboutPrefsUpdateTest(params, steps) {
       forceApply,
       expectedStateOverride,
     } = step;
-    return (async function() {
+    return (async function () {
       await SpecialPowers.spawn(
         tab.linkedBrowser,
         [{ panelId }],
@@ -1083,7 +1121,16 @@ function runAboutPrefsUpdateTest(params, steps) {
             let actualText = await SpecialPowers.spawn(
               tab.linkedBrowser,
               [],
-              () => content.document.getElementById("downloading").textContent
+              async () => {
+                const { document } = content;
+                if (document.hasPendingL10nMutations) {
+                  await ContentTaskUtils.waitForEvent(
+                    document,
+                    "L10nMutationsFinished"
+                  );
+                }
+                return document.getElementById("downloading").textContent;
+              }
             );
             let expectedSuffix = DownloadUtils.getTransferTotal(
               data[resultName] == gBadSizeResult ? 0 : patch.size,
@@ -1112,6 +1159,7 @@ function runAboutPrefsUpdateTest(params, steps) {
             "downloadFailed",
             "manualUpdate",
             "unsupportedSystem",
+            "internalError",
           ];
           if (linkPanels.includes(panelId)) {
             let { selectedPanel } = content.gAppUpdater;
@@ -1124,12 +1172,38 @@ function runAboutPrefsUpdateTest(params, steps) {
             if (selectedPanel.id == "downloadFailed") {
               selector = "a.text-link";
             }
+            // The manualUpdate panel in about:preferences uses
+            // the moz-support-link element which doesn't have
+            // the .text-link class.
+            if (selectedPanel.id == "manualUpdate") {
+              selector = "a.manualLink";
+            }
+            if (selectedPanel.ownerDocument.hasPendingL10nMutations) {
+              await ContentTaskUtils.waitForEvent(
+                selectedPanel.ownerDocument,
+                "L10nMutationsFinished"
+              );
+            }
             let link = selectedPanel.querySelector(selector);
             is(
               link.href,
               gDetailsURL,
               `The panel's link href should equal ${gDetailsURL}`
             );
+            const assertNonEmptyText = (node, description) => {
+              let textContent = node.textContent.trim();
+              ok(textContent, `${description}, got "${textContent}"`);
+            };
+            assertNonEmptyText(
+              link,
+              `The panel's link should have non-empty textContent`
+            );
+            let linkWrapperClone = link.parentNode.cloneNode(true);
+            linkWrapperClone.querySelector(selector).remove();
+            assertNonEmptyText(
+              linkWrapperClone,
+              `The panel's link should have text around the link`
+            );
           }
 
           let buttonPanels = ["downloadAndInstall", "apply"];
@@ -1150,7 +1224,7 @@ function runAboutPrefsUpdateTest(params, steps) {
     })();
   }
 
-  return (async function() {
+  return (async function () {
     Services.env.set("MOZ_TEST_SLOW_SKIP_UPDATE_STAGE", "1");
     await SpecialPowers.pushPrefEnv({
       set: [
@@ -1259,7 +1333,7 @@ function removeUpdateSettingsIni() {
  * @return A promise which will resolve after the .
  */
 function runTelemetryUpdateTest(updateParams, event, stageFailure = false) {
-  return (async function() {
+  return (async function () {
     Services.telemetry.clearScalars();
     Services.env.set("MOZ_TEST_SKIP_UPDATE_STAGE", "1");
     await SpecialPowers.pushPrefEnv({
