@@ -23,7 +23,7 @@ let types = {
   // so it is used here for this test.
   js: "application/x-javascript",
   binary: "application/octet-stream",
-  gook: "application/x-gook",
+  nonsense: "application/x-nonsense",
   zip: "application/zip",
   json: "application/json",
   tar: "application/x-tar",
@@ -55,7 +55,7 @@ const DEFAULT_FILENAME =
 const PROMISE_FILENAME_TYPE = "application/x-moz-file-promise-dest-filename";
 
 let MockFilePicker = SpecialPowers.MockFilePicker;
-MockFilePicker.init(window);
+MockFilePicker.init(window.browsingContext);
 
 let expectedItems;
 let sendAsAttachment = false;
@@ -116,19 +116,6 @@ function handleRedirect(aRequest, aResponse) {
   aResponse.setHeader("Location", "/bell" + filename[0] + "?" + queryString);
 }
 
-function promiseDownloadFinished(list) {
-  return new Promise(resolve => {
-    list.addView({
-      onDownloadChanged(download) {
-        if (download.stopped) {
-          list.removeView(this);
-          resolve(download);
-        }
-      },
-    });
-  });
-}
-
 // nsIFile::CreateUnique crops long filenames if the path is too long, but
 // we don't know exactly how long depending on the full path length, so
 // for those save methods that use CreateUnique, instead just verify that
@@ -149,18 +136,18 @@ function checkShortenedFilename(actual, expected) {
   return false;
 }
 
-add_setup(async function() {
-  const { HttpServer } = ChromeUtils.import(
-    "resource://testing-common/httpd.js"
+add_setup(async function () {
+  const { HttpServer } = ChromeUtils.importESModule(
+    "resource://testing-common/httpd.sys.mjs"
   );
   httpServer = new HttpServer();
   httpServer.start(8000);
 
   // Need to load the page from localhost:8000 as the download attribute
   // only applies to links from the same domain.
-  let saveFilenamesPage = FileUtils.getFile(
-    "CurWorkD",
-    "/browser/uriloader/exthandler/tests/mochitest/save_filenames.html".split(
+  let saveFilenamesPage = await IOUtils.getFile(
+    Services.dirsvc.get("CurWorkD", Ci.nsIFile).path,
+    ..."browser/uriloader/exthandler/tests/mochitest/save_filenames.html".split(
       "/"
     )
   );
@@ -202,12 +189,13 @@ function getItems(parentid) {
       while (elem) {
         let filename =
           elem.dataset["filenamePlatform" + platform] || elem.dataset.filename;
-        let url = elem.getAttribute("src");
+        let url = elem.getAttribute("src") || elem.getAttribute("href");
         let draggable =
           elem.localName == "img" && elem.dataset.nodrag != "true";
         let unknown = elem.dataset.unknown;
         let noattach = elem.dataset.noattach;
         let savepagename = elem.dataset.savepagename;
+        let pickedfilename = elem.dataset.pickedfilename;
         elements.push({
           draggable,
           unknown,
@@ -215,6 +203,7 @@ function getItems(parentid) {
           url,
           noattach,
           savepagename,
+          pickedfilename,
         });
         elem = elem.nextElementSibling;
       }
@@ -251,23 +240,13 @@ add_task(async function save_document() {
   tmpDir.append(baseFilename + "_document_files");
 
   MockFilePicker.displayDirectory = tmpDir;
-  MockFilePicker.showCallback = function(fp) {
+  MockFilePicker.showCallback = function () {
     MockFilePicker.setFiles([tmpFile]);
     MockFilePicker.filterIndex = 0; // kSaveAsType_Complete
   };
 
   let downloadsList = await Downloads.getList(Downloads.PUBLIC);
-  let savePromise = new Promise((resolve, reject) => {
-    downloadsList.addView({
-      onDownloadChanged(download) {
-        if (download.succeeded) {
-          downloadsList.removeView(this);
-          downloadsList.removeFinished();
-          resolve();
-        }
-      },
-    });
-  });
+  let savePromise = promiseDownloadFinished(downloadsList);
   saveBrowser(browser);
   await savePromise;
 
@@ -301,8 +280,9 @@ add_task(async function save_document() {
       fileIdx = filesSaved.indexOf(filename);
     }
 
-    ok(
-      fileIdx >= 0,
+    Assert.greaterOrEqual(
+      fileIdx,
+      0,
       "file i" +
         idx +
         " " +
@@ -319,6 +299,7 @@ add_task(async function save_document() {
   is(filesSaved.length, 0, "all files accounted for");
   tmpDir.remove(true);
   tmpFile.remove(false);
+  downloadsList.removeFinished();
 });
 
 // This test simulates dragging the images in the document and ensuring that
@@ -392,7 +373,11 @@ if (AppConstants.platform != "macosx") {
 
 // This test checks that copying an image provides the right filename
 // for pasting to the local file system. This is only implemented on Windows.
-if (AppConstants.platform == "win") {
+const imageAsFileEnabled = SpecialPowers.getBoolPref(
+  "clipboard.imageAsFile.enabled",
+  false
+);
+if (AppConstants.platform == "win" && imageAsFileEnabled) {
   add_task(async function copy_image() {
     for (let idx = 0; idx < expectedItems.length; idx++) {
       if (!expectedItems[idx].draggable) {
@@ -472,15 +457,28 @@ add_task(async function saveas_files() {
           let download = await downloadFinishedPromise;
 
           let filename = PathUtils.filename(download.target.path);
-          is(
-            filename,
-            expectedItems[idx].filename,
-            "open link" +
-              idx +
-              " " +
-              expectedItems[idx].filename +
-              " was downloaded with the correct name when opened as a url"
-          );
+
+          let expectedFilename = expectedItems[idx].filename;
+          if (expectedFilename.length > 240) {
+            ok(
+              checkShortenedFilename(filename, expectedFilename),
+              "open link" +
+                idx +
+                " " +
+                expectedFilename +
+                " was downloaded with the correct name when opened as a url (with long name)"
+            );
+          } else {
+            is(
+              filename,
+              expectedFilename,
+              "open link" +
+                idx +
+                " " +
+                expectedFilename +
+                " was downloaded with the correct name when opened as a url"
+            );
+          }
 
           try {
             await IOUtils.remove(download.target.path);
@@ -499,7 +497,7 @@ add_task(async function saveas_files() {
       }
 
       let filename = await new Promise(resolve => {
-        MockFilePicker.showCallback = function(fp) {
+        MockFilePicker.showCallback = function (fp) {
           setTimeout(() => {
             resolve(fp.defaultString);
           }, 0);
@@ -545,6 +543,59 @@ add_task(async function saveas_files() {
   }
 });
 
+// This test checks that the filename is saved correctly when it
+// has been modified within the file picker.
+add_task(async function saveas_files_modified_in_filepicker() {
+  let items = await getItems("modifieditems");
+  for (let idx = 0; idx < items.length; idx++) {
+    await BrowserTestUtils.openNewForegroundTab({
+      gBrowser,
+      opening: items[idx].url,
+      waitForLoad: false,
+      waitForStateStop: true,
+    });
+
+    let savedFile = SpecialPowers.Services.dirsvc.get("TmpD", Ci.nsIFile);
+
+    let downloadsList = await Downloads.getList(Downloads.PUBLIC);
+    let savePromise = promiseDownloadFinished(downloadsList);
+
+    await new Promise(resolve => {
+      MockFilePicker.displayDirectory = savedFile;
+
+      MockFilePicker.showCallback = function () {
+        MockFilePicker.filterIndex = 0; // kSaveAsType_Complete
+        savedFile.append(items[idx].pickedfilename);
+        MockFilePicker.setFiles([savedFile]);
+        setTimeout(() => {
+          resolve(items[idx].pickedfilename);
+        }, 0);
+
+        return Ci.nsIFilePicker.returnOK;
+      };
+
+      document.getElementById("Browser:SavePage").doCommand();
+    });
+
+    await savePromise;
+
+    savedFile.leafName = items[idx].filename;
+    ok(
+      savedFile.exists(),
+      "i" +
+        idx +
+        " '" +
+        savedFile.leafName +
+        "' was saved when modified with the correct name "
+    );
+    if (savedFile.exists()) {
+      savedFile.remove(false);
+    }
+
+    await BrowserTestUtils.removeTab(gBrowser.selectedTab);
+  }
+});
+
 // This test checks that links that result in files with
 // content-disposition: attachment are saved with the right filenames.
 add_task(async function save_links() {
@@ -645,7 +696,7 @@ add_task(async function saveas_image_links() {
       await popupShown;
 
       let promptPromise = new Promise(resolve => {
-        MockFilePicker.showCallback = function(fp) {
+        MockFilePicker.showCallback = function (fp) {
           setTimeout(() => {
             resolve(fp.defaultString);
           }, 0);
@@ -750,6 +801,33 @@ add_task(async function save_download_links() {
   }
 });
 
+// This test verifies that invalid extensions are not removed when they
+// have been entered in the file picker.
+add_task(async function save_page_with_invalid_after_filepicker() {
+  await BrowserTestUtils.openNewForegroundTab(
+    gBrowser,
+    "http://localhost:8000/save_filename.sjs?type=html&filename=invfile.lnk"
+  );
+
+  let filename = await new Promise(resolve => {
+    MockFilePicker.showCallback = function (fp) {
+      let expectedFilename =
+        AppConstants.platform == "win" ? "invfile.lnk.htm" : "invfile.lnk.html";
+      is(fp.defaultString, expectedFilename, "supplied filename is correct");
+      setTimeout(() => {
+        resolve("otherfile.local");
+      }, 0);
+      return Ci.nsIFilePicker.returnCancel;
+    };
+
+    document.getElementById("Browser:SavePage").doCommand();
+  });
+
+  is(filename, "otherfile.local", "lnk extension has been preserved");
+
+  await BrowserTestUtils.removeTab(gBrowser.selectedTab);
+});
+
 add_task(async function save_page_with_invalid_extension() {
   await BrowserTestUtils.openNewForegroundTab(
     gBrowser,
@@ -757,7 +835,7 @@ add_task(async function save_page_with_invalid_extension() {
   );
 
   let filename = await new Promise(resolve => {
-    MockFilePicker.showCallback = function(fp) {
+    MockFilePicker.showCallback = function (fp) {
       setTimeout(() => {
         resolve(fp.defaultString);
       }, 0);
