@@ -13,10 +13,11 @@
     static get fragment() {
       if (!this._template) {
         let parser = new DOMParser();
+        let cssPath = "chrome://global/content/elements/panel-list.css";
         let doc = parser.parseFromString(
           `
           <template>
-            <link rel="stylesheet" href="chrome://global/content/elements/panel-list.css">
+            <link rel="stylesheet" href=${cssPath}>
             <div class="arrow top" role="presentation"></div>
             <div class="list" role="presentation">
               <slot></slot>
@@ -31,26 +32,12 @@
           true
         );
       }
-      let frag = this._template.content.cloneNode(true);
-      if (window.IS_STORYBOOK) {
-        frag.querySelector("link").href = "./panel-list.css";
-      }
-      return frag;
+      return this._template.content.cloneNode(true);
     }
 
     constructor() {
       super();
       this.attachShadow({ mode: "open" });
-      // Ensure that the element is hidden even if its main stylesheet hasn't
-      // loaded yet. On initial load, or with cache disabled, the element could
-      // briefly flicker before the stylesheet is loaded without this.
-      let style = document.createElement("style");
-      style.textContent = `
-        :host(:not([open])) {
-          display: none;
-        }
-      `;
-      this.shadowRoot.appendChild(style);
       this.shadowRoot.appendChild(this.constructor.fragment);
     }
 
@@ -76,6 +63,14 @@
       this.toggleAttribute("open", val);
     }
 
+    get stayOpen() {
+      return this.hasAttribute("stay-open");
+    }
+
+    set stayOpen(val) {
+      this.toggleAttribute("stay-open", val);
+    }
+
     getTargetForEvent(event) {
       if (!event) {
         return null;
@@ -90,34 +85,46 @@
       return event._savedComposedTarget || event.target;
     }
 
-    show(triggeringEvent) {
+    show(triggeringEvent, target) {
       this.triggeringEvent = triggeringEvent;
-      this.lastAnchorNode = this.getTargetForEvent(this.triggeringEvent);
+      this.lastAnchorNode =
+        target || this.getTargetForEvent(this.triggeringEvent);
+
       this.wasOpenedByKeyboard =
         triggeringEvent &&
-        (triggeringEvent.mozInputSource == MouseEvent.MOZ_SOURCE_KEYBOARD ||
-          triggeringEvent.mozInputSource == MouseEvent.MOZ_SOURCE_UNKNOWN);
+        (triggeringEvent.inputSource == MouseEvent.MOZ_SOURCE_KEYBOARD ||
+          triggeringEvent.inputSource == MouseEvent.MOZ_SOURCE_UNKNOWN ||
+          triggeringEvent.code == "ArrowRight" ||
+          triggeringEvent.code == "ArrowLeft");
       this.open = true;
 
       if (this.parentIsXULPanel()) {
         this.toggleAttribute("inxulpanel", true);
         let panel = this.parentElement;
         panel.hidden = false;
-        panel.openPopup(
-          this.lastAnchorNode,
-          "after_start",
-          0,
-          0,
-          false,
-          false,
-          this.triggeringEvent
-        );
+        // Bug 1842070 - There appears to be a race here where panel-lists
+        // embedded in XUL panels won't appear during the first call to show()
+        // without waiting for a mix of rAF and another tick of the event
+        // loop.
+        requestAnimationFrame(() => {
+          setTimeout(() => {
+            panel.openPopup(
+              this.lastAnchorNode,
+              "after_start",
+              0,
+              0,
+              false,
+              false,
+              this.triggeringEvent
+            );
+          }, 0);
+        });
       } else {
         this.toggleAttribute("inxulpanel", false);
       }
     }
 
-    hide(triggeringEvent, { force = false } = {}) {
+    hide(triggeringEvent, { force = false } = {}, eventTarget) {
       // It's possible this is being used in an unprivileged context, in which
       // case it won't have access to Services / Services will be undeclared.
       const autohideDisabled = this.hasServices()
@@ -141,18 +148,18 @@
         panel.hidePopup();
       }
 
-      let target = this.getTargetForEvent(openingEvent);
+      let target = eventTarget || this.getTargetForEvent(openingEvent);
       // Refocus the button that opened the menu if we have one.
       if (target && this.wasOpenedByKeyboard) {
         target.focus();
       }
     }
 
-    toggle(triggeringEvent) {
+    toggle(triggeringEvent, target = null) {
       if (this.open) {
-        this.hide(triggeringEvent, { force: true });
+        this.hide(triggeringEvent, { force: true }, target);
       } else {
-        this.show(triggeringEvent);
+        this.show(triggeringEvent, target);
       }
     }
 
@@ -179,11 +186,9 @@
 
     async setAlign() {
       const hostElement = this.parentElement || this.getRootNode().host;
-      if (!hostElement || this.parentIsXULPanel()) {
+      if (!hostElement) {
         // This could get called before we're added to the DOM.
         // Nothing to do in that case.
-        //
-        // And if we're embedded in a XUL panel, let it handle alignment.
         return;
       }
 
@@ -195,7 +200,7 @@
 
       // Wait for a layout flush, then find the bounds.
       let {
-        anchorHeight,
+        anchorBottom, // distance from the bottom of the anchor el to top of viewport.
         anchorLeft,
         anchorTop,
         anchorWidth,
@@ -204,7 +209,7 @@
         winHeight,
         winScrollY,
         winScrollX,
-        winWidth,
+        clientWidth,
       } = await new Promise(resolve => {
         this.style.left = 0;
         this.style.top = 0;
@@ -222,7 +227,10 @@
             // Use y since top is reserved.
             let anchorBounds = getBounds(anchorElement);
             let panelBounds = getBounds(this);
+            let clientWidth = document.scrollingElement.clientWidth;
+
             resolve({
+              anchorBottom: anchorBounds.bottom,
               anchorHeight: anchorBounds.height,
               anchorLeft: anchorBounds.left,
               anchorTop: anchorBounds.top,
@@ -230,58 +238,85 @@
               panelHeight: panelBounds.height,
               panelWidth: panelBounds.width,
               winHeight: innerHeight,
-              winWidth: innerWidth,
               winScrollX: scrollX,
               winScrollY: scrollY,
+              clientWidth,
             });
           }, 0)
         );
       });
 
-      // Calculate the left/right alignment.
-      let align;
-      let leftOffset;
-      let leftAlignX = anchorLeft;
-      let rightAlignX = anchorLeft + anchorWidth - panelWidth;
+      // If we're embedded in a XUL panel, let it handle alignment.
+      if (!this.parentIsXULPanel()) {
+        // Calculate the left/right alignment.
+        let align;
+        let leftOffset;
+        let leftAlignX = anchorLeft;
+        let rightAlignX = anchorLeft + anchorWidth - panelWidth;
 
-      if (this.isDocumentRTL()) {
-        // Prefer aligning on the right.
-        align = rightAlignX < 0 ? "left" : "right";
-      } else {
-        // Prefer aligning on the left.
-        align = leftAlignX + panelWidth > winWidth ? "right" : "left";
-      }
-      leftOffset = align === "left" ? leftAlignX : rightAlignX;
+        if (this.isDocumentRTL()) {
+          // Prefer aligning on the right.
+          align = rightAlignX < 0 ? "left" : "right";
+        } else {
+          // Prefer aligning on the left.
+          align = leftAlignX + panelWidth > clientWidth ? "right" : "left";
+        }
+        leftOffset = align === "left" ? leftAlignX : rightAlignX;
 
-      let bottomAlignY = anchorTop + anchorHeight;
-      let valign;
-      let topOffset;
-      if (bottomAlignY + panelHeight > winHeight) {
-        topOffset = anchorTop - panelHeight;
-        valign = "top";
-      } else {
-        topOffset = bottomAlignY;
-        valign = "bottom";
+        let bottomSpaceY = winHeight - anchorBottom;
+
+        let valign;
+        let topOffset;
+        const VIEWPORT_PANEL_MIN_MARGIN = 10; // 10px ensures that the panel is not flush with the viewport.
+
+        // Only want to valign top when there's more space between the bottom of the anchor element and the top of the viewport.
+        // If there's more space between the bottom of the anchor element and the bottom of the viewport, we valign bottom.
+        if (
+          anchorBottom > bottomSpaceY &&
+          anchorBottom + panelHeight > winHeight
+        ) {
+          // Never want to have a negative value for topOffset, so ensure it's at least 10px.
+          topOffset = Math.max(
+            anchorTop - panelHeight,
+            VIEWPORT_PANEL_MIN_MARGIN
+          );
+          // Provide a max-height for larger elements which will provide scrolling as needed.
+          this.style.maxHeight = `${anchorTop + VIEWPORT_PANEL_MIN_MARGIN}px`;
+          valign = "top";
+        } else {
+          topOffset = anchorBottom;
+          this.style.maxHeight = `${
+            bottomSpaceY - VIEWPORT_PANEL_MIN_MARGIN
+          }px`;
+          valign = "bottom";
+        }
+
+        // Set the alignments and show the panel.
+        this.setAttribute("align", align);
+        this.setAttribute("valign", valign);
+        hostElement.style.overflow = "";
+
+        this.style.left = `${leftOffset + winScrollX}px`;
+        this.style.top = `${topOffset + winScrollY}px`;
       }
 
-      // Set the alignments and show the panel.
-      this.setAttribute("align", align);
-      this.setAttribute("valign", valign);
-      hostElement.style.overflow = "";
-
-      this.style.left = `${leftOffset + winScrollX}px`;
-      this.style.top = `${topOffset + winScrollY}px`;
+      this.style.minWidth = this.hasAttribute("min-width-from-anchor")
+        ? `${anchorWidth}px`
+        : "";
 
       this.removeAttribute("showing");
     }
 
     addHideListeners() {
-      if (this.hasAttribute("stay-open")) {
+      if (this.hasAttribute("stay-open") && !this.lastAnchorNode?.hasSubmenu) {
         // This is intended for inspection in Storybook.
         return;
       }
       // Hide when a panel-item is clicked in the list.
       this.addEventListener("click", this);
+      // Allows submenus to stopPropagation when focus is already in the menu
+      this.addEventListener("keydown", this);
+      // We need Escape/Tab/ArrowDown to work when opened with the mouse.
       document.addEventListener("keydown", this);
       // Hide when a click is initiated outside the panel.
       document.addEventListener("mousedown", this);
@@ -300,6 +335,7 @@
 
     removeHideListeners() {
       this.removeEventListener("click", this);
+      this.removeEventListener("keydown", this);
       document.removeEventListener("keydown", this);
       document.removeEventListener("mousedown", this);
       document.removeEventListener("focusin", this);
@@ -325,6 +361,10 @@
       switch (e.type) {
         case "resize":
         case "scroll":
+          if (inPanelList) {
+            break;
+          }
+        // Intentional fall-through
         case "blur":
         case "popuphidden":
           this.hide();
@@ -353,19 +393,15 @@
             // Don't scroll the page or let the regular tab order take effect.
             e.preventDefault();
 
+            // Prevents the host panel list from responding to these events while
+            // the submenu is active.
+            e.stopPropagation();
+
             // Keep moving to the next/previous element sibling until we find a
             // panel-item that isn't hidden.
             let moveForward =
               e.key === "ArrowDown" || (e.key === "Tab" && !e.shiftKey);
 
-            // If the menu is opened with the mouse, the active element might be
-            // somewhere else in the document. In that case we should ignore it
-            // to avoid walking unrelated DOM nodes.
-            this.focusWalker.currentNode = this.contains(
-              this.getRootNode().activeElement
-            )
-              ? this.getRootNode().activeElement
-              : this;
             let nextItem = moveForward
               ? this.focusWalker.nextNode()
               : this.focusWalker.previousNode();
@@ -403,10 +439,6 @@
             // using the mouse. Ignore the first focusin event if it's on the
             // triggering target.
             this.focusHasChanged = true;
-          } else if (!target || !inPanelList) {
-            // If the target isn't in the panel, hide. This will close when focus
-            // moves out of the panel.
-            this.hide();
           } else {
             // Just record that there was a focusin event.
             this.focusHasChanged = true;
@@ -454,18 +486,90 @@
       }
       return this._focusWalker;
     }
+    async setSubmenuAlign() {
+      const hostElement =
+        this.lastAnchorNode.parentElement || this.getRootNode().host;
+      // The showing attribute allows layout of the panel while remaining hidden
+      // from the user until alignment is set.
+      this.setAttribute("showing", "true");
+
+      // Wait for a layout flush, then find the bounds.
+      let {
+        anchorLeft,
+        anchorWidth,
+        anchorTop,
+        parentPanelTop,
+        panelWidth,
+        clientWidth,
+      } = await new Promise(resolve => {
+        requestAnimationFrame(() => {
+          // It's possible this is being used in a context where windowUtils is
+          // not available. In that case, fallback to using the element.
+          let getBounds = el =>
+            window.windowUtils
+              ? window.windowUtils.getBoundsWithoutFlushing(el)
+              : el.getBoundingClientRect();
+          // submenu item in the parent panel list
+          let anchorBounds = getBounds(this.lastAnchorNode);
+          let parentPanelBounds = getBounds(hostElement);
+          let panelBounds = getBounds(this);
+          let clientWidth = document.scrollingElement.clientWidth;
+
+          resolve({
+            anchorLeft: anchorBounds.left,
+            anchorWidth: anchorBounds.width,
+            anchorTop: anchorBounds.top,
+            parentPanelTop: parentPanelBounds.top,
+            panelWidth: panelBounds.width,
+            clientWidth,
+          });
+        });
+      });
+
+      let align = hostElement.getAttribute("align");
+
+      // we use document.scrollingElement.clientWidth to exclude the width
+      // of vertical scrollbars, because its inclusion can cause the submenu
+      // to open to the wrong side and be overlapped by the scrollbar.
+      if (
+        align == "left" &&
+        anchorLeft + anchorWidth + panelWidth < clientWidth
+      ) {
+        this.style.left = `${anchorWidth}px`;
+        this.style.right = "";
+      } else {
+        this.style.right = `${anchorWidth}px`;
+        this.style.left = "";
+      }
+
+      let topOffset =
+        anchorTop -
+        parentPanelTop -
+        (parseFloat(window.getComputedStyle(this)?.paddingTop) || 0);
+      this.style.top = `${topOffset}px`;
+
+      this.removeAttribute("showing");
+    }
 
     async onShow() {
       this.sendEvent("showing");
       this.addHideListeners();
-      await this.setAlign();
+
+      if (this.lastAnchorNode?.hasSubmenu) {
+        await this.setSubmenuAlign();
+      } else {
+        await this.setAlign();
+      }
+
+      // Always reset this regardless of how the panel list is opened
+      // so the first child will be focusable.
+      this.focusWalker.currentNode = this;
 
       // Wait until the next paint for the alignment to be set and panel to be
       // visible.
       requestAnimationFrame(() => {
         if (this.wasOpenedByKeyboard) {
           // Focus the first focusable panel-item if opened by keyboard.
-          this.focusWalker.currentNode = this;
           this.focusWalker.nextNode();
         }
 
@@ -484,7 +588,9 @@
     }
 
     sendEvent(name, detail) {
-      this.dispatchEvent(new CustomEvent(name, { detail }));
+      this.dispatchEvent(
+        new CustomEvent(name, { detail, bubbles: true, composed: true })
+      );
     }
   }
   customElements.define("panel-list", PanelList);
@@ -503,18 +609,16 @@
 
       let style = document.createElement("link");
       style.rel = "stylesheet";
-      style.href = window.IS_STORYBOOK
-        ? "./panel-item.css"
-        : "chrome://global/content/elements/panel-item.css";
+      style.href = "chrome://global/content/elements/panel-item.css";
 
       this.button = document.createElement("button");
       this.button.setAttribute("role", "menuitem");
       this.button.setAttribute("part", "button");
-
       // Use a XUL label element if possible to show the accesskey.
       this.label = document.createXULElement
         ? document.createXULElement("label")
         : document.createElement("span");
+
       this.button.appendChild(this.label);
 
       let supportLinkSlot = document.createElement("slot");
@@ -532,6 +636,15 @@
     }
 
     connectedCallback() {
+      if (!this._l10nRootConnected && document.l10n) {
+        document.l10n.connectRoot(this.shadowRoot);
+        this._l10nRootConnected = true;
+      }
+
+      this.panel =
+        this.getRootNode()?.host?.closest("panel-list") ||
+        this.closest("panel-list");
+
       if (!this.#initialized) {
         this.#initialized = true;
         // When click listeners are added to the panel-item it creates a node in
@@ -549,22 +662,58 @@
           childList: true,
           subtree: true,
         });
-      }
 
-      this.panel = this.closest("panel-list");
+        if (this.hasSubmenu) {
+          this.panel.setAttribute("has-submenu", "");
+          this.icon = document.createElement("div");
+          this.icon.setAttribute("class", "submenu-icon");
+          this.label.setAttribute("class", "submenu-label");
+
+          this.button.setAttribute("class", "submenu-container");
+          this.button.appendChild(this.icon);
+
+          this.submenuSlot = document.createElement("slot");
+          this.submenuSlot.name = "submenu";
+
+          this.shadowRoot.append(this.submenuSlot);
+
+          this.setSubmenuContents();
+        }
+      }
 
       if (this.panel) {
         this.panel.addEventListener("hidden", this);
         this.panel.addEventListener("shown", this);
       }
+
+      if (this.hasSubmenu) {
+        this.addEventListener("mouseenter", this);
+        this.addEventListener("mouseleave", this);
+        this.addEventListener("keydown", this);
+      }
     }
 
     disconnectedCallback() {
+      if (this._l10nRootConnected) {
+        document.l10n.disconnectRoot(this.shadowRoot);
+        this._l10nRootConnected = false;
+      }
+
       if (this.panel) {
         this.panel.removeEventListener("hidden", this);
         this.panel.removeEventListener("shown", this);
         this.panel = null;
       }
+
+      if (this.hasSubmenu) {
+        this.removeEventListener("mouseenter", this);
+        this.removeEventListener("mouseleave", this);
+        this.removeEventListener("keydown", this);
+      }
+    }
+
+    get hasSubmenu() {
+      return this.hasAttribute("submenu");
     }
 
     attributeChangedCallback(name, oldVal, newVal) {
@@ -602,6 +751,13 @@
         .join("");
     }
 
+    setSubmenuContents() {
+      this.submenuPanel = this.submenuSlot.assignedNodes()[0];
+      if (this.submenuPanel) {
+        this.shadowRoot.append(this.submenuPanel);
+      }
+    }
+
     get disabled() {
       return this.button.hasAttribute("disabled");
     }
@@ -622,6 +778,17 @@
       this.button.focus();
     }
 
+    setArrowKeyRTL() {
+      let arrowOpenKey = "ArrowRight";
+      let arrowCloseKey = "ArrowLeft";
+
+      if (this.submenuPanel.isDocumentRTL()) {
+        arrowOpenKey = "ArrowLeft";
+        arrowCloseKey = "ArrowRight";
+      }
+      return [arrowOpenKey, arrowCloseKey];
+    }
+
     handleEvent(e) {
       // Bug 1588156 - Accesskey is not ignored for hidden non-input elements.
       // Since the accesskey won't be ignored, we need to remove it ourselves
@@ -640,6 +807,21 @@
             this.accessKey = "";
           }
           break;
+        case "mouseenter":
+        case "mouseleave":
+          this.submenuPanel.toggle(e);
+          break;
+        case "keydown":
+          let [arrowOpenKey, arrowCloseKey] = this.setArrowKeyRTL();
+          if (e.key === arrowOpenKey) {
+            this.submenuPanel.show(e, e.target);
+            e.stopPropagation();
+          }
+          if (e.key === arrowCloseKey) {
+            this.submenuPanel.hide(e, { force: true }, e.target);
+            e.stopPropagation();
+          }
+          break;
       }
     }
   }
